
# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.accounts_api import AccountsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from delphix.api.gateway.api.accounts_api import AccountsApi
from delphix.api.gateway.api.ai_generate_api import AiGenerateApi
from delphix.api.gateway.api.ai_management_api import AiManagementApi
from delphix.api.gateway.api.algorithms_api import AlgorithmsApi
from delphix.api.gateway.api.authorization_api import AuthorizationApi
from delphix.api.gateway.api.bookmarks_api import BookmarksApi
from delphix.api.gateway.api.cdb_d_sources_api import CDBDSourcesApi
from delphix.api.gateway.api.cdbs_api import CDBsApi
from delphix.api.gateway.api.classifiers_api import ClassifiersApi
from delphix.api.gateway.api.cloud_accounts_api import CloudAccountsApi
from delphix.api.gateway.api.compliance_job_collections_api import ComplianceJobCollectionsApi
from delphix.api.gateway.api.compliance_jobs_api import ComplianceJobsApi
from delphix.api.gateway.api.compliance_nodes_api import ComplianceNodesApi
from delphix.api.gateway.api.connectivity_api import ConnectivityApi
from delphix.api.gateway.api.connectors_api import ConnectorsApi
from delphix.api.gateway.api.d_sources_api import DSourcesApi
from delphix.api.gateway.api.data_classes_api import DataClassesApi
from delphix.api.gateway.api.data_connections_api import DataConnectionsApi
from delphix.api.gateway.api.data_layouts_api import DataLayoutsApi
from delphix.api.gateway.api.data_library_api import DataLibraryApi
from delphix.api.gateway.api.database_templates_api import DatabaseTemplatesApi
from delphix.api.gateway.api.discovery_expressions_api import DiscoveryExpressionsApi
from delphix.api.gateway.api.discovery_policies_api import DiscoveryPoliciesApi
from delphix.api.gateway.api.environments_api import EnvironmentsApi
from delphix.api.gateway.api.executions_api import ExecutionsApi
from delphix.api.gateway.api.file_mapping_api import FileMappingApi
from delphix.api.gateway.api.groups_api import GroupsApi
from delphix.api.gateway.api.held_space_api import HeldSpaceApi
from delphix.api.gateway.api.hook_templates_api import HookTemplatesApi
from delphix.api.gateway.api.hyperscale_instance_api import HyperscaleInstanceApi
from delphix.api.gateway.api.hyperscale_objects_api import HyperscaleObjectsApi
from delphix.api.gateway.api.job_collection_executions_api import JobCollectionExecutionsApi
from delphix.api.gateway.api.job_orchestrators_api import JobOrchestratorsApi
from delphix.api.gateway.api.jobs_api import JobsApi
from delphix.api.gateway.api.kerberos_config_api import KerberosConfigApi
from delphix.api.gateway.api.license_api import LicenseApi
from delphix.api.gateway.api.login_api import LoginApi
from delphix.api.gateway.api.management_api import ManagementApi
from delphix.api.gateway.api.masking_environments_api import MaskingEnvironmentsApi
from delphix.api.gateway.api.masking_files_api import MaskingFilesApi
from delphix.api.gateway.api.masking_jobs_api import MaskingJobsApi
from delphix.api.gateway.api.masking_plugins_api import MaskingPluginsApi
from delphix.api.gateway.api.namespace_api import NamespaceApi
from delphix.api.gateway.api.network_performance_tool_api import NetworkPerformanceToolApi
from delphix.api.gateway.api.paa_s_database_api import PaaSDatabaseApi
from delphix.api.gateway.api.paa_s_databases_api import PaaSDatabasesApi
from delphix.api.gateway.api.paa_s_instances_api import PaaSInstancesApi
from delphix.api.gateway.api.paa_s_plugins_api import PaaSPluginsApi
from delphix.api.gateway.api.paa_s_snapshots_api import PaaSSnapshotsApi
from delphix.api.gateway.api.paas_instance_api import PaasInstanceApi
from delphix.api.gateway.api.password_vaults_api import PasswordVaultsApi
from delphix.api.gateway.api.replication_api import ReplicationApi
from delphix.api.gateway.api.reporting_api import ReportingApi
from delphix.api.gateway.api.rule_sets_api import RuleSetsApi
from delphix.api.gateway.api.saml_login_api import SamlLoginApi
from delphix.api.gateway.api.snapshots_api import SnapshotsApi
from delphix.api.gateway.api.sources_api import SourcesApi
from delphix.api.gateway.api.staging_cdbs_api import StagingCdbsApi
from delphix.api.gateway.api.staging_sources_api import StagingSourcesApi
from delphix.api.gateway.api.storage_usage_api import StorageUsageApi
from delphix.api.gateway.api.tags_api import TagsApi
from delphix.api.gateway.api.timeflows_api import TimeflowsApi
from delphix.api.gateway.api.toolkits_api import ToolkitsApi
from delphix.api.gateway.api.vcdbs_api import VCDBsApi
from delphix.api.gateway.api.vdb_groups_api import VDBGroupsApi
from delphix.api.gateway.api.vdbs_api import VDBsApi
from delphix.api.gateway.api.virtualization_actions_api import VirtualizationActionsApi
from delphix.api.gateway.api.virtualization_alerts_api import VirtualizationAlertsApi
from delphix.api.gateway.api.virtualization_faults_api import VirtualizationFaultsApi
from delphix.api.gateway.api.virtualization_jobs_api import VirtualizationJobsApi
from delphix.api.gateway.api.virtualization_policies_api import VirtualizationPoliciesApi



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.network_dsp_test_request import NetworkDSPTestRequest
from delphix.api.gateway.model.network_dsp_test_result_all_of import NetworkDSPTestResultAllOf
from delphix.api.gateway.model.network_test_base_result import NetworkTestBaseResult
globals()['NetworkDSPTestRequest'] = NetworkDSPTestRequest
globals()['NetworkDSPTestResultAllOf'] = NetworkDSPTestResultAllOf
globals()['NetworkTestBaseResult'] = NetworkTestBaseResult
from delphix.api.gateway.model.network_dsp_test_result import NetworkDSPTestResult


class TestNetworkDSPTestResult(unittest.TestCase):
    """NetworkDSPTestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkDSPTestResult(self):
        """Test NetworkDSPTestResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkDSPTestResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.license_api import LicenseApi  # noqa: E501


class TestLicenseApi(unittest.TestCase):
    """LicenseApi unit test stubs"""

    def setUp(self):
        self.api = LicenseApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_license(self):
        """Test case for change_license

        Change the current DCT license.  # noqa: E501
        """
        pass

    def test_get_license(self):
        """Test case for get_license

        Returns the DCT license information.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.ai_management_api import AiManagementApi  # noqa: E501


class TestAiManagementApi(unittest.TestCase):
    """AiManagementApi unit test stubs"""

    def setUp(self):
        self.api = AiManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_llm_gateways(self):
        """Test case for get_all_llm_gateways

        Get the details of all available gateways  # noqa: E501
        """
        pass

    def test_get_all_llm_models(self):
        """Test case for get_all_llm_models

        Get the details of all available Llm models  # noqa: E501
        """
        pass

    def test_get_llm_model(self):
        """Test case for get_llm_model

        Get the details of an LLM model  # noqa: E501
        """
        pass

    def test_upload_model(self):
        """Test case for upload_model

        Upload the model file and register it with Ollama service  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.virtualization_policies_api import VirtualizationPoliciesApi  # noqa: E501


class TestVirtualizationPoliciesApi(unittest.TestCase):
    """VirtualizationPoliciesApi unit test stubs"""

    def setUp(self):
        self.api = VirtualizationPoliciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_apply_virtualization_policy_by_id_or_name(self):
        """Test case for apply_virtualization_policy_by_id_or_name

        Apply a virtualization policy to the given list of objects.  # noqa: E501
        """
        pass

    def test_convert_virtualization_policy(self):
        """Test case for convert_virtualization_policy

        Convert a virtualization policy to a DCT-managed policy.  # noqa: E501
        """
        pass

    def test_create_virtualization_policy(self):
        """Test case for create_virtualization_policy

        Create a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_create_virtualization_policy_tags(self):
        """Test case for create_virtualization_policy_tags

        Create tags for a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_delete_virtualization_policy(self):
        """Test case for delete_virtualization_policy

        Delete a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_delete_virtualization_policy_tags(self):
        """Test case for delete_virtualization_policy_tags

        Delete tags for a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_get_virtualization_policy_by_id(self):
        """Test case for get_virtualization_policy_by_id

        Fetch a virtualization policy by Id.  # noqa: E501
        """
        pass

    def test_get_virtualization_policy_tags(self):
        """Test case for get_virtualization_policy_tags

        Get tags for a VirtualizationPolicy.  # noqa: E501
        """
        pass

    def test_list_virtualization_policies(self):
        """Test case for list_virtualization_policies

        Fetch a list of all virtualization policies  # noqa: E501
        """
        pass

    def test_search_virtualization_policies(self):
        """Test case for search_virtualization_policies

        Search Virtualization Policies.  # noqa: E501
        """
        pass

    def test_search_virtualization_policy_targets(self):
        """Test case for search_virtualization_policy_targets

        Search Virtualization Policy Target Objects.  # noqa: E501
        """
        pass

    def test_unapply_virtualization_policy_by_id_or_name(self):
        """Test case for unapply_virtualization_policy_by_id_or_name

        Unapply a virtualization policy to the given list of objects.  # noqa: E501
        """
        pass

    def test_update_virtualization_policy(self):
        """Test case for update_virtualization_policy

        Update a VirtualizationPolicy.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.license_usage_response_current_sources_size import LicenseUsageResponseCurrentSourcesSize
from delphix.api.gateway.model.license_usage_response_other_entitlements import LicenseUsageResponseOtherEntitlements
from delphix.api.gateway.model.license_usage_response_source_type_count import LicenseUsageResponseSourceTypeCount
globals()['LicenseUsageResponseCurrentSourcesSize'] = LicenseUsageResponseCurrentSourcesSize
globals()['LicenseUsageResponseOtherEntitlements'] = LicenseUsageResponseOtherEntitlements
globals()['LicenseUsageResponseSourceTypeCount'] = LicenseUsageResponseSourceTypeCount
from delphix.api.gateway.model.license_usage_response import LicenseUsageResponse


class TestLicenseUsageResponse(unittest.TestCase):
    """LicenseUsageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLicenseUsageResponse(self):
        """Test LicenseUsageResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = LicenseUsageResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.rule_sets_api import RuleSetsApi  # noqa: E501


class TestRuleSetsApi(unittest.TestCase):
    """RuleSetsApi unit test stubs"""

    def setUp(self):
        self.api = RuleSetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_bulk_table_delta_update_rule_set(self):
        """Test case for bulk_table_delta_update_rule_set

        Update the set of tables and their attributes associated with a database rule set in bulk in a delta fashion.  # noqa: E501
        """
        pass

    def test_create_rule_set(self):
        """Test case for create_rule_set

        Create a Rule Set.  # noqa: E501
        """
        pass

    def test_create_rule_set_tags(self):
        """Test case for create_rule_set_tags

        Create tags for a Rule Set.  # noqa: E501
        """
        pass

    def test_delete_rule_set(self):
        """Test case for delete_rule_set

        Delete a Rule Set.  # noqa: E501
        """
        pass

    def test_delete_rule_set_tags(self):
        """Test case for delete_rule_set_tags

        Delete tags for a Rule Set.  # noqa: E501
        """
        pass

    def test_get_database_column_metadata(self):
        """Test case for get_database_column_metadata

        Retrieve column metadata.  # noqa: E501
        """
        pass

    def test_get_database_column_metadata_by_id(self):
        """Test case for get_database_column_metadata_by_id

        Retrieve a database column metadata by ID.  # noqa: E501
        """
        pass

    def test_get_database_table_metadata(self):
        """Test case for get_database_table_metadata

        Retrieve table metadata.  # noqa: E501
        """
        pass

    def test_get_database_table_metadata_by_id(self):
        """Test case for get_database_table_metadata_by_id

        Retrieve a database table metadata by ID.  # noqa: E501
        """
        pass

    def test_get_rule_set_by_id(self):
        """Test case for get_rule_set_by_id

        Get a Rule Set by ID.  # noqa: E501
        """
        pass

    def test_get_rule_set_tags(self):
        """Test case for get_rule_set_tags

        Get tags for a Rule Set.  # noqa: E501
        """
        pass

    def test_get_rule_sets(self):
        """Test case for get_rule_sets

        Retrieve the list of Rule Sets.  # noqa: E501
        """
        pass

    def test_refresh_rule_set(self):
        """Test case for refresh_rule_set

        Refresh a Rule Set.  # noqa: E501
        """
        pass

    def test_search_database_column_metadata(self):
        """Test case for search_database_column_metadata

        Search column metadata.  # noqa: E501
        """
        pass

    def test_search_database_table_metadata(self):
        """Test case for search_database_table_metadata

        Search table metadata.  # noqa: E501
        """
        pass

    def test_search_rule_sets(self):
        """Test case for search_rule_sets

        Search for Rule Sets.  # noqa: E501
        """
        pass

    def test_update_database_column_metadata(self):
        """Test case for update_database_column_metadata

        Update a database column metadata  # noqa: E501
        """
        pass

    def test_update_rule_set(self):
        """Test case for update_rule_set

        Update a Rule Set.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.reporting_api import ReportingApi  # noqa: E501


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self):
        self.api = ReportingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_reporting_schedule(self):
        """Test case for create_reporting_schedule

        Create a new report schedule.  # noqa: E501
        """
        pass

    def test_create_reporting_schedule_tags(self):
        """Test case for create_reporting_schedule_tags

        Create tags for a report schedule.  # noqa: E501
        """
        pass

    def test_delete_reporting_schedule(self):
        """Test case for delete_reporting_schedule

        Delete report schedule by ID.  # noqa: E501
        """
        pass

    def test_delete_reporting_schedule_tag(self):
        """Test case for delete_reporting_schedule_tag

        Delete tags for a report schedule.  # noqa: E501
        """
        pass

    def test_download_execution_pdf_report(self):
        """Test case for download_execution_pdf_report

        Download PDF report for given execution.  # noqa: E501
        """
        pass

    def test_generate_execution_pdf_report(self):
        """Test case for generate_execution_pdf_report

        Generate a PDF report for given execution.  # noqa: E501
        """
        pass

    def test_get_api_usage_report(self):
        """Test case for get_api_usage_report

        Gets the report of API usage metrics over a given time period. This API returns at the most 10000 results in the response to protect against the server running out of memory. Users might not hit this limit with the default report without any 'apiUsageReportGroupByParam' param but can hit this limit if the groupBy is by too granular like by 'client_name' or 'user_agent' only. Hence it is advisable to use startDate and endDate to 'limit' the scope of the report.  # noqa: E501
        """
        pass

    def test_get_audit_logs_summary_report(self):
        """Test case for get_audit_logs_summary_report

        Gets the audit log summary report.  # noqa: E501
        """
        pass

    def test_get_data_risk_report(self):
        """Test case for get_data_risk_report

        Get the masking data risk report.  # noqa: E501
        """
        pass

    def test_get_dataset_performance_analytics(self):
        """Test case for get_dataset_performance_analytics

        Get Dataset Performance analytics  # noqa: E501
        """
        pass

    def test_get_dsource_consumption_report(self):
        """Test case for get_dsource_consumption_report

        Gets the consumption report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_get_dsource_usage_report(self):
        """Test case for get_dsource_usage_report

        Gets the usage report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_get_engine_global_object_state_report(self):
        """Test case for get_engine_global_object_state_report

        Get the masking engine global object state report.  # noqa: E501
        """
        pass

    def test_get_engine_performance_analytics_report(self):
        """Test case for get_engine_performance_analytics_report

        Gets the performance analytics report for engines.  # noqa: E501
        """
        pass

    def test_get_masking_execution_metrics_report(self):
        """Test case for get_masking_execution_metrics_report

        Get the masking execution metrics report.  # noqa: E501
        """
        pass

    def test_get_product_info(self):
        """Test case for get_product_info

        Returns the DCT Product Information.  # noqa: E501
        """
        pass

    def test_get_reporting_schedule_by_id(self):
        """Test case for get_reporting_schedule_by_id

        Returns a report schedule by ID.  # noqa: E501
        """
        pass

    def test_get_reporting_schedule_tags(self):
        """Test case for get_reporting_schedule_tags

        Get tags for a report schedule.  # noqa: E501
        """
        pass

    def test_get_reporting_schedules(self):
        """Test case for get_reporting_schedules

        List all report schedules.  # noqa: E501
        """
        pass

    def test_get_storage_capacity_data(self):
        """Test case for get_storage_capacity_data

        Get engine storage capacity data.  # noqa: E501
        """
        pass

    def test_get_vdb_inventory_report(self):
        """Test case for get_vdb_inventory_report

        Gets the inventory report for virtualization engine VDBs.  # noqa: E501
        """
        pass

    def test_get_virtualization_storage_summary_report(self):
        """Test case for get_virtualization_storage_summary_report

        Gets the storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_search_data_risk_report(self):
        """Test case for search_data_risk_report

        Search the masking data risk report.  # noqa: E501
        """
        pass

    def test_search_dataset_performance_analytics_summary(self):
        """Test case for search_dataset_performance_analytics_summary

        Search Dataset Performance analytics summary  # noqa: E501
        """
        pass

    def test_search_dsource_consumption_report(self):
        """Test case for search_dsource_consumption_report

        Search the consumption report for virtualization engine DSources.  # noqa: E501
        """
        pass

    def test_search_dsource_usage_report(self):
        """Test case for search_dsource_usage_report

        Search the usage report for virtualization engine dSources.  # noqa: E501
        """
        pass

    def test_search_engine_global_object_state_report(self):
        """Test case for search_engine_global_object_state_report

        Search the masking engine global object state report.  # noqa: E501
        """
        pass

    def test_search_engine_performance_analytic_trends(self):
        """Test case for search_engine_performance_analytic_trends

        Search the performance analytic trend data for engines.  # noqa: E501
        """
        pass

    def test_search_engine_performance_analytics_report(self):
        """Test case for search_engine_performance_analytics_report

        Search the performance analytic report for engines.  # noqa: E501
        """
        pass

    def test_search_masking_execution_metrics_report(self):
        """Test case for search_masking_execution_metrics_report

        Search the Masking execution metrics report.  # noqa: E501
        """
        pass

    def test_search_reporting_schedules(self):
        """Test case for search_reporting_schedules

        Search for report schedules.  # noqa: E501
        """
        pass

    def test_search_storage_capacity_data(self):
        """Test case for search_storage_capacity_data

        Search engine storage capacity data.  # noqa: E501
        """
        pass

    def test_search_storage_savings_summary_report(self):
        """Test case for search_storage_savings_summary_report

        Search the saving storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_search_vdb_inventory_report(self):
        """Test case for search_vdb_inventory_report

        Search the inventory report for virtualization engine VDBs.  # noqa: E501
        """
        pass

    def test_search_virtualization_storage_summary_report(self):
        """Test case for search_virtualization_storage_summary_report

        Search the storage summary report for virtualization engines.  # noqa: E501
        """
        pass

    def test_update_reporting_schedule(self):
        """Test case for update_reporting_schedule

        Update a reporting schedule by ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
